@@ -3,17 +3,12 @@ import ast
 import os
 import re
 import traceback
+from typing import Any, Dict, Optional, Union
 
-try:  # py27
-    from urllib.parse import urljoin
-except ImportError:
-    from urlparse import urljoin
-try:  # py27
-    from urllib.request import pathname2url
-except ImportError:
-    from urllib import pathname2url
+from urllib.parse import urljoin
+from urllib.request import pathname2url
 
-from packaging import requirements, specifiers
+from packaging import requirements, specifiers  # type: ignore
 
 from pip_api.exceptions import PipError
 
@@ -170,7 +165,9 @@ def _ignore_comments(lines_enum):
             yield line_number, line
 
 
-def parse_requirements(filename, options=None, include_invalid=False):
+def parse_requirements(
+    filename: os.PathLike, options: Optional[Any] = None, include_invalid: bool = False
+) -> Dict[str, Union[requirements.Requirement, UnparsedRequirement]]:
     to_parse = {filename}
     parsed = set()
     name_to_req = {}
@@ -187,7 +184,7 @@ def parse_requirements(filename, options=None, include_invalid=False):
         lines_enum = _skip_regex(lines_enum, options)
 
         for lineno, line in lines_enum:
-            req = None
+            req: Optional[Union[requirements.Requirement, UnparsedRequirement]] = None
             known, _ = parser.parse_known_args(line.strip().split())
             if known.req:
                 try:  # Try to parse this as a requirement specification
@@ -216,7 +213,7 @@ def parse_requirements(filename, options=None, include_invalid=False):
             # If we've found a requirement, add it
             if req:
                 if not isinstance(req, UnparsedRequirement):
-                    req.comes_from = "-r {} (line {})".format(filename, lineno)
+                    req.comes_from = "-r {} (line {})".format(filename, lineno)  # type: ignore
 
                 if req.name not in name_to_req:
                     name_to_req[req.name.lower()] = req
